{% load i18n %}
{% load infinite_scroll %}
<html>
    <head>
        <meta name='robots' content='noindex, nofollow'>
    </head>
    <body>
        {% for item in feed %}
            {{ item }}
        {% endfor %}
        {% infinite_scroll_tags %}
    </body>
</html>
