<input type="hidden" id="prev_page" value="{{ newer_posts }}"/>
<input type="hidden" id="next_page" value="{{ older_posts }}"/>
<input type="hidden" id="has_more" value="{{ has_older_posts }}"/>
<input type="hidden" id="keep_loading" value="{{ should_load_more }}"/>
